==> troubleshooting-framework-1.2.5.7.tar.gz: troubleshooting-framework-1.2.5.7/src/troubleshooting/framework/httpserver/www/cgi-bin/index.py <==
#!/usr/bin/env python
from troubleshooting.framework.modules.configuration import  ConfigManagerInstance
from troubleshooting.framework.running.recovery import recovery
from os.path import abspath,dirname,join
import cgi
import os,sys

form = cgi.FieldStorage()
homeDir = dirname(dirname(abspath(__file__)))



if form.has_key("Recovery"):
    #recovery mode
    ProjectDir = form.getvalue("ProjectDir").replace("/",os.path.sep)

    sys.path.append(ProjectDir)
    ConfigManagerInstance.config = {"Recovery":form.getvalue("Recovery")}
    if form.getvalue("Host") == "localhost":
        ConfigManagerInstance.config = {"Host": None}
    else:
        ConfigManagerInstance.config = {"Host": form.getvalue("Host")}
    ConfigManagerInstance.config = {"Port": form.getvalue("Port")}
    ConfigManagerInstance.config = {"User": form.getvalue("User")}
    ConfigManagerInstance.config = {"Password": form.getvalue("Password")}
    ConfigManagerInstance.config = {"__ReportHash__": form.getvalue("reportHash")}
    ConfigManagerInstance.config = {"__ProjectCWD__": form.getvalue("ProjectDir")}
    ConfigManagerInstance.config = {"R_TestPoint": form.getvalue("TestPoint") }

    if ConfigManagerInstance.config["Recovery"]:
        print "Content-Type: text/html"  # HTML is following
        print  # blank line, end of headers
        recovery(ConfigManagerInstance.config["Recovery"])




else:
    #generate mode
    if form.has_key("reportHash") and form.has_key("reportName"):
        index_page = join(homeDir, form.getvalue("reportHash"), form.getvalue("reportName"))

        print "Content-Type: text/html"     # HTML is following
        print                               # blank line, end of headers
        try:
            with open(index_page,"rb") as f:
                print f.read()
        except IOError,e:
            error_page = join(homeDir,"others","404.html")
            with open(error_page,"rb") as f:
                print f.read()
    else:
        print "Content-Type: text/html"     # HTML is following
        print                               # blank line, end of headers
        error_page = join(homeDir, "others", "404.html")
        with open(error_page, "rb") as f:
            print f.read()

==> troubleshooting-framework-1.2.6.0.tar.gz: troubleshooting-framework-1.2.6.0/src/troubleshooting/framework/httpserver/www/cgi-bin/index.py <==
#!/usr/bin/env python
from troubleshooting.framework.modules.configuration import  ConfigManagerInstance
from troubleshooting.framework.running.recovery import recovery
from os.path import abspath,dirname,join
import cgi
import os,sys
from troubleshooting.framework.libraries.system import get_FileCreateTime,get_FileModifyTime
from troubleshooting.framework.libraries.parsexml import parsexml

form = cgi.FieldStorage()
homeDir = dirname(dirname(abspath(__file__)))



if form.has_key("Recovery"):
    #recovery mode
    ProjectDir = form.getvalue("ProjectDir").replace("/",os.path.sep)

    sys.path.append(ProjectDir)
    ConfigManagerInstance.config = {"Recovery":form.getvalue("Recovery")}
    if form.getvalue("Host") == "localhost":
        ConfigManagerInstance.config = {"Host": None}
    else:
        ConfigManagerInstance.config = {"Host": form.getvalue("Host")}
    ConfigManagerInstance.config = {"Port": form.getvalue("Port")}
    ConfigManagerInstance.config = {"User": form.getvalue("User")}
    ConfigManagerInstance.config = {"Password": form.getvalue("Password")}
    ConfigManagerInstance.config = {"__ReportHash__": form.getvalue("reportHash")}
    ConfigManagerInstance.config = {"__ProjectCWD__": form.getvalue("ProjectDir")}
    ConfigManagerInstance.config = {"R_TestPoint": form.getvalue("TestPoint") }

    if ConfigManagerInstance.config["Recovery"]:
        print "Content-Type: text/html"  # HTML is following
        print  # blank line, end of headers
        recovery(ConfigManagerInstance.config["Recovery"])




else:
    #generate mode
    if form.has_key("reportHash"):
        index_page = join(homeDir, form.getvalue("reportHash"), "report.html")

        print "Content-Type: text/html"     # HTML is following
        print                               # blank line, end of headers
        try:
            with open(index_page,"rb") as f:
                print f.read()
        except IOError,e:
            error_page = join(homeDir,"others","404.html")
            with open(error_page,"rb") as f:
                print f.read()
    else:
        print "Content-Type: text/html"     # HTML is following
        print                               # blank line, end of headers
        if not form.has_key("reportHash"):
            hashlink = []
            for _fileName in os.listdir(homeDir):
                if _fileName.endswith(".d"):
                    _filepath = join(homeDir,_fileName)
                    fileCreateTime = get_FileCreateTime(_filepath)
                    fileModifyTime = get_FileModifyTime(_filepath)
                    dataxmlpath = join(_filepath,"data.xml")
                    pass_num,fail_num = parsexml().get_cases_status(dataxmlpath)
                    hashlink.append('<li><div>%s</div><a href="http://localhost:8888/www/cgi-bin/index.py?reportHash=%s">report linkage (pass %s/fail %s)</a></li>'%(fileCreateTime,_fileName,pass_num,fail_num))
            linkage = "</br>".join(hashlink)

            html = """
        <html>
        <head>
        </head>
        <body>
        %s
        </body>
        </html>
        """%linkage
            print html
